#VT50-2013-2016-84-28-6
#Copyright (c) 2018 Veritas Technologies LLC. All rights reserved.  Veritas
#and the Veritas Logo are trademarks or registered trademarks of Veritas 
#Technologies LLC or its affiliates in the U.S. and other countries. 
#Other names may be trademarks of their respective owners.
#
#The Licensed Software and Documentation are deemed to be commercial computer 
#software as defined in FAR 12.212 and subject to restricted rights as defined 
#in FAR Section 52.227-19 "Commercial Computer Software - Restricted Rights" and 
#DFARS 227.7202, et seq. "Commercial Computer Software and Commercial Computer 
#Software Documentation," as applicable, and any successor regulations, whether 
#delivered by Veritas as on premises or hosted services.  Any use, modification, 
#reproduction release, performance, display or disclosure of the Licensed Software 
#and Documentation by the U.S. Government shall be solely in accordance with the 
#terms of this Agreement.


#!/bin/sh

#keeps result in $res. stores acceptance level in $add_res

check_acceptance() {

	res=1
	add_res=`esxcli software acceptance get`;

	if [ "$add_res" = "VMwareCertified" ]; then
		res=1;
	else
		res=0;
	fi
	return
}

check_host_conn() {

	res=1;
	add_res=`ping $host`;

	if [ $? -eq 0 ]; then
		res=0;
	else
		res=1;
	fi
	return
}

check_host_ip() {

	res=1;
	t=`nslookup $host`;

	if [ $? -eq 0 ]; then
		res=0;
	else
		res=1;
	fi
	return;
}

check_service() {
	res=1;
	t=`/etc/init.d/iofiltervpd status | grep "not running"`;

	if [ $? -eq 0 ]; then
		res=1;
	else
		res=0;
	fi
	return
}

check_host_port() {

	res=1;
	t=`nc -zv $host $port | grep "succeeded"`;
	
	if [ $? -eq 0 ]; then
		res=0;
	else
		res=1;
	fi
	return
}

check_version() {

	res=1;
	maj=`vmware -l | cut -f 3 -d ' ' | cut -f 1 -d '.'`;
	min=`vmware -l | cut -f 3 -d ' ' | cut -f 1 -d '.'`;
	update=`vmware -l | cut -f 5 -d ' '`;
	
	if [ ! -z "$update" ]; then
		if [[ "$maj" -lt 6 ]] || [[ "$maj" -eq 6 -a "$min" -eq 0 -a "$update" -lt 2 ]]; then
			res=1;
		else
			res=0;
		fi
	else
		update=`vmware -l | cut -f 4 -d ' '`;
		if [[ "$maj" -lt 6 ]] || [[ "$maj" -eq 6 -a "$min" -eq 0 -a "$update" != "GA" ]]; then
			res=1;
		else
			res=0;
		fi
	fi
	return
}

#set $input before calling this function

print_result() {

	if [ $res -eq 0 ]; then
		echo "$input:     [success]"
	else
		echo "$input:     [failed]"
	fi
	return
}

#Following is the main script

#parse arguments

if [ $# -ge 2 ]; then
	host_type=$1;
	host=$2;
else
	echo "Usage: check_esx [vcenter|ims|gateway] <host_name>";
	exit;
fi

#checking acceptance level

check_acceptance;
input="Checking acceptance level";
print_result;
if [ $res -ne 0 ]; then
	echo "\t value set to $add_res";
else
	echo "acceptance level is $add_res";
fi

#checking esxi version

check_version;
input="Checking ESXi version";
print_result;

echo "ESXi version is `vmware -l`";

if [ $res -ne 0 ]; then
	echo "Not performing more validations as ESXi version not supported";
	exit;
fi

#checking connectivity with host

check_host_conn;
input="Checking connection to host $host"
print_result;
if [ $res -ne 0 ]; then
	echo "ping output $add_res";
fi

#checking host name to IP address mapping

check_host_ip;
input="Checking host $host to IP mapping"
print_result;

#checking iofiltervpd service status
check_service; 
input="Checking iofiltervpd service"
print_result;

if [ "$host_type" = "gateway" ]; then
	port=33056;
	check_host_port;
	input="Checking gateway $host port 33056"
	print_result;
fi
#if [ "$host_type" = "vcenter" ]; then
#	port=443;
#	check_host_port;
#	input="Checking vCenter $host port 443"
#	print_result;
#fi
