#VT50-2013-2016-84-28-6
#Copyright (c) 2018 Veritas Technologies LLC. All rights reserved.  Veritas
#and the Veritas Logo are trademarks or registered trademarks of Veritas 
#Technologies LLC or its affiliates in the U.S. and other countries. 
#Other names may be trademarks of their respective owners.
#
#The Licensed Software and Documentation are deemed to be commercial computer 
#software as defined in FAR 12.212 and subject to restricted rights as defined 
#in FAR Section 52.227-19 "Commercial Computer Software - Restricted Rights" and 
#DFARS 227.7202, et seq. "Commercial Computer Software and Commercial Computer 
#Software Documentation," as applicable, and any successor regulations, whether 
#delivered by Veritas as on premises or hosted services.  Any use, modification, 
#reproduction release, performance, display or disclosure of the Licensed Software 
#and Documentation by the U.S. Government shall be solely in accordance with the 
#terms of this Agreement.


function CheckResolution
{
    param
    (
        $HostNameList
    )
    $CheckName = "Check for DNS Resolution"
    $Status = 0
    foreach($HostName in $HostNameList){
        Try
        {
            $Address = [System.Net.Dns]::GetHostAddresses($HostName)
            $Name = [System.Net.Dns]::GetHostByAddress($Address).HostName
        }
        Catch
        {
            $ErrorMsg = ""
            if($_.Exception.InnerException)
            {
                $ErrorMsg = $_.Exception.InnerException.Message
            }
            else
            {
                $ErrorMsg = $_.Exception.Message
            }
            $Status = 1
            Write-Host "$CheckName [Failed]: for $HostName:: $ErrorMsg"

        }
    }
    if($Status -eq 0)
    {
        Write-Host "$CheckName [Passed]"
    }
}

function CheckServerPort
{
    param
    (
        $Server,
        $Port
    )
    $CheckName = "Check if IMS port 14161 is accessible"
    Try
    {
        $TcpClient = New-Object System.Net.Sockets.TcpClient
        $TcpClient.Connect($Server, $Port)
        if($TcpClient.Connected)
        {
            $TcpClient.Close();
            Write-Host "$CheckName [Passed]"
        }
        else
        {
            throw "$CheckName [Failed]:: Could not connect to $Server port: 14161"
        }
    }
    Catch
    {
        $ErrorMsg
        if($_.Exception.InnerException)
        {
            $ErrorMsg = $_.Exception.InnerException.Message
        }
        else
        {
            $ErrorMsg = $_.Exception.Message
        }
        Write-Host "$CheckName [Failed]:: $ErrorMsg"
    }
}

function CheckVCServices
{
    $ServiceList = ("VMwareIdentityMgmtService", "vmware-psc-client", "VMWareCertificateService", 
                        "VMWareDirectoryService", "VMwareSTS", "vimPBSM")
    Write-Host "Check if required services are running"
	$ins = Get-ItemProperty -Path "HKLM:\SOFTWARE\VMware, Inc.\vCenter Server"
	$psc_type = $ins.INSTALL_TYPE

	if ($ins.INSTALL_TYPE -eq "embedded")
	{
		foreach ($ServiceName in $ServiceList)
		{
			$output = & .\service-control --status $ServiceName
			Write-Host "$output"
		}
	}
	else
	{
		Write-Host "vCenter with external PSC, Checking limited services"
		$output = & .\service-control --status "vimPBSM"
		Write-Host "$output"
		Write-Host "To check other services, run check_psc_services script on extenal PSC"
	}
}

if ($args.Count -lt 2)
{
    Write-Host "Usage: check_vcenter.ps1 <ims|esx> <hostname>"
    exit
}
if ($args[0] -eq "ims" -and $args.Count -gt 2)
{
    Write-Host "Please provide single IMS hostname."
    exit
}

CheckVCServices
CheckResolution -HostName $args[1..$args.Count]
if ($args[0] -eq "ims")
{
    CheckServerPort -Server $args[1] 14161
}
