#VT50-2013-2016-84-28-6
#Copyright (c) 2018 Veritas Technologies LLC. All rights reserved.  Veritas
#and the Veritas Logo are trademarks or registered trademarks of Veritas 
#Technologies LLC or its affiliates in the U.S. and other countries. 
#Other names may be trademarks of their respective owners.
#
#The Licensed Software and Documentation are deemed to be commercial computer 
#software as defined in FAR 12.212 and subject to restricted rights as defined 
#in FAR Section 52.227-19 "Commercial Computer Software - Restricted Rights" and 
#DFARS 227.7202, et seq. "Commercial Computer Software and Commercial Computer 
#Software Documentation," as applicable, and any successor regulations, whether 
#delivered by Veritas as on premises or hosted services.  Any use, modification, 
#reproduction release, performance, display or disclosure of the Licensed Software 
#and Documentation by the U.S. Government shall be solely in accordance with the 
#terms of this Agreement.

#!/usr/bin/sh

# Use it on vCenter

check_host_ip() {

	res=1;
	if [ "$host_type" = "esx" ]; then
		for myhost in "${esx_array[@]}"
		do
			t=`nslookup $myhost`;
			if [ $? -eq 0 ]; then
				res=0;
			else
				res=1;
			fi
			input="Checking $myhost to ip address mapping"
			print_result;
		done
	else
		t=`nslookup $host`;
		if [ $? -eq 0 ]; then
			res=0;
		else
			res=1;
		fi
		input="Checking $host to ip address mapping"
		print_result;
	fi
	return
}

check_host_conn() {
	
	res=1;
	add_res=""
	if [ "$host_type" = "esx" ]; then
		for esxhost in "${esx_array[@]}"
		do
			add_res=`ping $esxhost -w 2`;

			if [ $? -eq 0 ]; then
				res=0;
			else
				res=1;
			fi
			input="Checking connection to $esxhost"
			print_result;
			if [ $res -ne 0 ]; then
				if [ -z "$add_res" ]; then
					add_res="Host not reachable"
				fi
				echo "ping output $add_res";
			fi

		done
	else
		add_res=`ping $host -w 2`;
		if [ $? -eq 0 ]; then
			res=0;
		else
			res=1;
		fi
		input="Checking connection to $host"
		print_result;
		if [ $res -ne 0 ]; then
			if [ -z "$add_res" ]; then
				add_res="Host not reachable"
			fi
			echo "ping output $add_res";
		fi

	fi


	return
}

check_host_port() {

	res=1;
	#add_res=`traceroute -T -w 1 -p 14161 $host`;
	#t=`traceroute -T -w 1 -p 14161 $host | grep " \* \* \*"`;
	add_res=`nc -z $host 14161`;

	if [ $? -eq 0 ]; then
		res=0;
	else
		res=1;
	fi
	return
}


check_vc_services() {
	res=1;
	service_array=( vmware-sts-idmd vmware-psc-client vmware-stsd vmcad vmdird vmware-sps )
	
	echo "Checking services on vcenter: ";
	vc_host_name=`cat /etc/hostname`
	psc_name=`/usr/lib/vmware-vmafd/bin/vmafd-cli get-ls-location --server-name localhost`

	if [[ "$psc_name" =~ "$vc_host_name" ]]; then
		psc_external=0;
	else
		psc_external=1;
	fi

	if [ $psc_external -eq 0 ]; then
		for service_name in "${service_array[@]}"
		do
			serv_status=`service-control --status $service_name`
			if [ $? -eq 1 ]; then
				echo "Failed to retreive status of service: $service_name" ;
			fi
			echo "$serv_status" ;
		done
	else
		echo "vCenter with external PSC, Checking limited services";
		serv_status=`service-control --status vmware-sps`
		echo "$serv_status";
		echo "To check other services, run check_psc_services script on extenal PSC";
	fi
	return

}

# set $input before calling this function

print_result() {
	if [ $res -eq 0 ]; then
		echo "$input:      [success]";
	else
		echo "$input:      [failed]";
	fi
	return
}

# following is the main script

# parse arguments

index=0
if [ $# -ge 2 ]; then
	host_type=$1;  # can be either esx or ims
	if [ "$host_type" = "esx" ]; then
		for temp_host in "${@:2}"
		do
			esx_array[$index]=$temp_host
			(( index++ ))
		done
	else 
		if [ "$host_type" = "ims" ]; then
			if [ $# -ge 3 ]; then
				echo "Please provide single IMS hostname"
				exit;
			else  
				host=$2;
			fi
		fi
	fi
else
	echo "Usage: check_vcenter [esx|ims] <host_name>";
	exit;
fi

# check host name to ip mapping
check_host_ip;

# check host connection
check_host_conn;

# check vcenter services
check_vc_services;

# check ims port
if [ "$host_type" = "ims" ]; then
	check_host_port;
	input="Checking 14161 port of ims $host"
	print_result;
	#echo "traceroute output $add_res";
fi
